=============
Release Notes
=============

.. towncrier release notes start

0.1.0 (2018-06-13)
------------------

Features
````````

- Create *plume* package that simulates 1D (i.e. centerline), and 2D hypopycnal
  plumes.

Documentation Enhancements
``````````````````````````

- Added a new *Jupyter* notebook that demonstrates how to use simulate 2D and 1D
  plumes using the *plume* package. (`#3 <https://github.com/mcflugen/plume/issues/3>`_)


Other Changes and Additions
```````````````````````````

- Set up continuous integration testing with Travis-CI. CI builds are run
  for Linux and Mac. Windows support is not yet available. (`#1 <https://github.com/mcflugen/plume/issues/1>`_)
- Added a suite of tests, which use *pytest*, for testing the *plume*
  package. (`#2 <https://github.com/mcflugen/plume/issues/2>`_)
- Added *versioneer* to manage package release versions. (`#4 <https://github.com/mcflugen/plume/issues/4>`_)
